#  Copyright (c) 2022.
#  All rights reserved to the creator of the following script/program/app, please do not
#  use or distribute without prior authorization from the creator.
#  Creator: Antonio Manuel Nunes Goncalves
#  Email: amng835@gmail.com
#  LinkedIn: https://www.linkedin.com/in/antonio-manuel-goncalves-983926142/
#  Github: https://github.com/DEADSEC-SECURITY

# Built-In Imports
import os
import shutil
from abc import ABC

# 3rd-Party Imports
from pathlib import Path

from aws_cdk import aws_lambda as lambda_


# Local Imports

class Build:
    project_path: Path
    work_dir: Path
    # Internal
    _build_dir: Path
    _project_build_dir: Path
    _req_file: Path

    def __init__(self, project_path: str, work_dir: str):
        self.project_path = Path(project_path).resolve()
        self.work_dir = Path(work_dir).resolve()

        self._build_dir = self.work_dir.joinpath('.build')
        self._project_build_dir = self._build_dir.joinpath(self.project_path.parts[-1])
        self._req_file = self._project_build_dir.joinpath('requirements.txt')

    def build(self):
        if not os.path.isdir(self._build_dir):
            os.mkdir(self._build_dir)

        if os.path.isdir(self._project_build_dir):
            shutil.rmtree(self._project_build_dir)

        shutil.copytree(self.project_path, self._project_build_dir)

        os.system(f'pip3 install -r {self._req_file} -t {self._project_build_dir}')

        return lambda_.Code.from_asset(self._project_build_dir.as_posix())


#  Copyright (c) 2022.
#  All rights reserved to the creator of the following script/program/app, please do not
#  use or distribute without prior authorization from the creator.
#  Creator: Antonio Manuel Nunes Goncalves
#  Email: amng835@gmail.com
#  LinkedIn: https://www.linkedin.com/in/antonio-manuel-goncalves-983926142/
#  Github: https://github.com/DEADSEC-SECURITY

# Built-In Imports

# 3rd-Party Imports
from setuptools import find_packages, setup
import pathlib

# Local Imports

README = (pathlib.Path(__file__).parent / "README.md").read_text(encoding='utf8')

setup(
    name='aws-cdk-code-builder',
    packages=find_packages(),
    version='1.0.0',
    description='A Library that extends the aws_lambda.Code.from_asset and allows for auto '
                'packaging of the project',
    long_description=README,
    long_description_content_type='text/markdown',
    author='DeadSec-Security',
    author_email='amng835@gmail.com',
    url='https://github.com/DEADSEC-SECURITY/aws-cdk-code-builder',
    install_requires=[
        'aws-cdk-lib==2.50.0',
    ],
    keywords=[
        'aws_cdk',
        'aws_cdk_build',
        'aws_cdk_packaging'
    ],
    python_requires='>=3.7'
)
